Description Usage Arguments Value Examples
Compress sequential parts in a vector of prefixed numbers.
1 | compress(xs, sep = "--", level = 3)
|
xs |
a vector of prefixed numbers (character strings) |
sep |
a character string to represent sequencial prefixed numbers |
level |
sequencial parts of length longer than or equal to |
a vector of prefixed numbers in which sequential parts are compressed (character strings)
1 2 3 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.