Description Usage Arguments Value Examples
This is a wrapper for functions enum_inline, enum_bullet, and
enum_numbered. If bullet or init option is neither NULL nor
FALSE, then it generates a bullet list or a numbered list appropriately.
Otherwise, it enumerates the elements inline.
If both bullet and init options are neither NULL nor FALSE, a
numbered list precedes a bullet list.
1 |
xs |
a vector of elements to be enumerated |
sep |
a character string to separate the elements if inline |
bullet |
possibly bool or a character string. If |
init |
possibly bool or a number. If |
a character string enumerating the elements
1 2 3 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.