Description Usage Arguments Value Examples
Enumerate elements in a bullet list.
1 | enum_bullet(xs, bullet = "-")
|
xs |
a vector of elements to be enumerated |
bullet |
a character string to be used as bullet points |
a character string enumerating the elements in a bullet list
1 2 | enum_bullet(1:3) #=> "- 1\n- 2\n- 3"
enum_bullet(1:3, bullet = "*") #=> "* 1\n* 2\n* 3"
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.